@@ -22,7 +22,7 @@ json_pack <- function(.data, ..., .names_sep = NULL) {
 
 #' @export
 json_pack.data.frame <- function(.data, ..., .names_sep = NULL) {
-  check_suggested("jsonlite", use = TRUE, top_level_fun = "json_pack")
+  check_suggested("jsonlite", "json_pack")
   dot_nms <- ...names()
   tidyr::pack(.data, ..., .names_sep = .names_sep) %>%
     mutate(across(all_of(dot_nms), to_packed_json))
@@ -66,6 +66,8 @@ sql_json_pack <- function(con, cols, names_sep, packed_col, data, ...) {
 #' @autoglobal
 #' @global JSON_BUILD_OBJECT
 sql_json_pack.PqConnection <- function(con, cols, names_sep, packed_col, data, ...) {
+  check_dots_empty()
+
   inside_cols <- remove_prefix_and_sep(cols, prefix = packed_col, sep = names_sep)
   inside_cols_idented <- dbplyr::ident(inside_cols)
   exprs <- vctrs::vec_interleave(as.list(inside_cols_idented), syms(cols))
@@ -73,7 +75,9 @@ sql_json_pack.PqConnection <- function(con, cols, names_sep, packed_col, data, .
 }
 
 remove_prefix_and_sep <- function(x, prefix, sep) {
-  if (is.null(sep)) return(x)
+  if (is.null(sep)) {
+    return(x)
+  }
   prefix_and_sep <- paste0(prefix, sep)
   prefixed_lgl <- startsWith(x, prefix_and_sep)
   # `substr()` rather than `sub()` to avoid escaping special regex chars
@@ -82,16 +86,6 @@ remove_prefix_and_sep <- function(x, prefix, sep) {
 }
 
 
-#' @export
-#' @autoglobal
-#' @global JSON_AGG JSON_BUILD_OBJECT
-sql_json_nest.PqConnection <- function(con, cols, names_sep, packed_col, id_cols, data, ...) {
-  inside_cols <- remove_prefix_and_sep(cols, prefix = packed_col, sep = names_sep)
-  inside_cols_idented <- dbplyr::ident(inside_cols)
-  exprs <- vctrs::vec_interleave(as.list(inside_cols_idented), syms(cols))
-  dbplyr::translate_sql(JSON_AGG(JSON_BUILD_OBJECT(!!!exprs)), con = con)
-}
-
 #' @export
 `json_pack.tbl_Microsoft SQL Server` <- function(.data, ..., .names_sep = NULL) {
   dots <- quos(...)
