@@ -91,8 +91,6 @@ test_that("dm() works for adding tables", {
     dm(dm_for_filter(), tf_7_new = tf_7()) %>% dm_select_tbl(tf_1, tf_7_new, everything())
   )
 
-  skip_if_not_installed("dbplyr")
-
   # error in case table srcs don't match
   expect_dm_error(
     dm(dm_for_filter(), data_card_1_duckdb()),
@@ -125,7 +123,7 @@ test_that("dm() works for dm objects", {
       dm_get_def(dm_for_flatten()),
       dm_get_def(dm_for_disambiguate())
     ) %>%
-      new_dm3()
+      dm_from_def()
   )
 })
 
@@ -151,8 +149,6 @@ test_that("errors: duplicate table names, src mismatches", {
     dm(dm_for_filter(), dm_for_flatten(), dm_for_filter())
   })
 
-  skip_if_not_installed("dbplyr")
-  skip_if_not_installed("duckdb")
   expect_dm_error(dm(dm_for_flatten(), dm_for_filter_duckdb()), "not_same_src")
 })
 
@@ -184,7 +180,7 @@ test_that("auto-renaming works", {
         tf_6...17 = tf_6
       ))
     ) %>%
-      new_dm3()
+      dm_from_def()
   )
 
   expect_silent(
@@ -193,7 +189,6 @@ test_that("auto-renaming works", {
 })
 
 test_that("test error output for src mismatches", {
-  skip_if_not_installed("dbplyr")
   skip_if_not(getRversion() >= "4.0")
 
   expect_snapshot({
@@ -210,11 +205,15 @@ test_that("output for dm() with dm", {
     dm(dm_for_filter()) %>% collect()
     dm(dm_for_filter(), dm_for_flatten(), dm_for_filter(), .name_repair = "unique", .quiet = TRUE) %>% collect()
   })
+})
 
+test_that("output for dm() with dm (2)", {
   expect_snapshot(error = TRUE, {
     dm(dm_for_filter(), dm_for_flatten(), dm_for_filter())
   })
+})
 
+test_that("output for dm() with dm (3)", {
   expect_snapshot({
     dm(dm_for_filter(), dm_for_flatten(), dm_for_filter(), .name_repair = "unique") %>% collect()
   })
@@ -354,7 +353,20 @@ test_that("`pull_tbl()`-methods work", {
     pull_tbl(dm_for_filter(), tf_5, keyed = TRUE),
     dm_get_tables(dm_for_filter(), keyed = TRUE)[["tf_5"]]
   )
+})
 
+test_that("`pull_tbl()`-methods work for (0)", {
+  tbl <-
+    dm_nycflights_small() %>%
+    dm_set_table_description("Flugzeuge" = planes) %>%
+    pull_tbl(planes, keyed = TRUE)
+
+  skip_if_not_installed("labelled")
+
+  expect_identical(labelled::label_attribute(tbl), "Flugzeuge")
+})
+
+test_that("`pull_tbl()`-methods work for (1)", {
   skip_if_src("maria")
   expect_equivalent_tbl(
     dm_for_filter() %>%
@@ -385,7 +397,7 @@ test_that("`pull_tbl()`-methods work (2)", {
     dm_for_filter() %>%
       dm_get_def() %>%
       mutate(zoom = list(tf_1)) %>%
-      new_dm3(zoomed = TRUE, validate = FALSE) %>%
+      dm_from_def(zoomed = TRUE, validate = FALSE) %>%
       pull_tbl(),
     "not_pulling_multiple_zoomed"
   )
@@ -469,8 +481,6 @@ test_that("dm_get_con() errors", {
 })
 
 test_that("dm_get_con() works", {
-  skip_if_not_installed("dbplyr")
-
   expect_identical(
     dm_get_con(dm_for_filter_db()),
     con_from_src_or_con(my_db_test_src())
@@ -492,8 +502,6 @@ test_that("str()", {
 })
 
 test_that("output", {
-  skip_if_not_installed("nycflights13")
-
   expect_snapshot({
     print(dm())
 
