@@ -8,7 +8,7 @@ test_that("Standard learning from MSSQL (schema 'dbo') or Postgres (schema 'publ
   withr::defer(
     try(walk(
       remote_tbl_names,
-      ~ try(dbExecute(con_db, paste0("DROP TABLE ", .x)))
+      ~ try(DBI::dbExecute(con_db, paste0("DROP TABLE ", .x)))
     ))
   )
 
@@ -20,7 +20,7 @@ test_that("Standard learning from MSSQL (schema 'dbo') or Postgres (schema 'publ
       dm_get_tables(dm_for_filter_copied)[order_of_deletion],
       dbplyr::remote_name
     ) %>%
-    SQL() %>%
+    DBI::SQL() %>%
     DBI::dbUnquoteIdentifier(conn = con_db) %>%
     map_chr(~ .x@name[["table"]])
 
@@ -51,7 +51,7 @@ test_that("Standard learning from MSSQL (schema 'dbo') or Postgres (schema 'publ
       pks = list_of(new_pk()),
       fks = list_of(new_fk())
     ) %>%
-    new_dm3()
+    dm_from_def()
 
   # Select and fix table names
   dm_db_learned_no_keys <-
@@ -65,7 +65,7 @@ test_that("Standard learning from MSSQL (schema 'dbo') or Postgres (schema 'publ
 })
 
 
-test_that("Learning from specific schema on MSSQL or Postgres works?", {
+test_that("Learning from specific schema works?", {
   skip_if_schema_not_supported()
 
   # produces a randomized schema name with a length of 4-10 characters
@@ -92,16 +92,16 @@ test_that("Learning from specific schema on MSSQL or Postgres works?", {
   )
   order_of_deletion <- c("iris_3", "iris_2", "iris_1")
   remote_tbl_names <- set_names(
-    paste0(schema_name_q, ".\"", order_of_deletion, "\""),
+    paste0(schema_name_q, ".", DBI::dbQuoteIdentifier(con_db, order_of_deletion)),
     order_of_deletion
   )
 
   withr::defer({
     walk(
       remote_tbl_names,
-      ~ try(dbExecute(con_db, paste0("DROP TABLE ", .x)))
+      ~ try(DBI::dbExecute(con_db, paste0("DROP TABLE ", .x)))
     )
-    try(dbExecute(con_db, paste0("DROP SCHEMA ", schema_name_q)))
+    try(DBI::dbExecute(con_db, paste0("DROP SCHEMA ", schema_name_q)))
   })
 
   normalize_table_name <- function(x) {
@@ -114,8 +114,8 @@ test_that("Learning from specific schema on MSSQL or Postgres works?", {
     ~ DBI::dbQuoteIdentifier(con_db, .x)
   )
   expect_identical(
-    sort(normalize_table_name(SQL(src_tbl_names))),
-    SQL(sort(normalize_table_name(remote_tbl_names)))
+    sort(normalize_table_name(DBI::SQL(src_tbl_names))),
+    DBI::SQL(sort(normalize_table_name(remote_tbl_names)))
   )
 
   # learning with keys:
@@ -142,7 +142,7 @@ test_that("Learning from specific schema on MSSQL or Postgres works?", {
       pks = list_of(new_pk()),
       fks = list_of(new_fk())
     ) %>%
-    new_dm3()
+    dm_from_def()
 
   expect_equivalent_dm(
     dm_db_learned_no_keys,
@@ -167,8 +167,6 @@ test_that("Learning from SQLite works (#288)?", {
 
 
 test_that("'schema_if()' works", {
-  skip_if_not_installed("dbplyr")
-
   con_db <- my_db_test_src()$con
 
   # all 3 naming parameters set ('table' is required)
@@ -211,19 +209,19 @@ test_that("Learning from MSSQL (schema 'dbo') on other DB works?", {
 
   # delete database after test
   withr::defer({
-    try(dbExecute(con_db, "DROP TABLE [test_database_dm].[dbo].[test_2]"))
-    try(dbExecute(con_db, "DROP TABLE [test_database_dm].[dbo].[test_1]"))
-    try(dbExecute(con_db, "DROP DATABASE test_database_dm"))
+    try(DBI::dbExecute(con_db, "DROP TABLE [test_database_dm].[dbo].[test_2]"))
+    try(DBI::dbExecute(con_db, "DROP TABLE [test_database_dm].[dbo].[test_1]"))
+    try(DBI::dbExecute(con_db, "DROP DATABASE test_database_dm"))
   })
 
   # create another DB and 2 connected tables
   DBI::dbExecute(con_db, "CREATE DATABASE test_database_dm")
-  dbWriteTable(
+  DBI::dbWriteTable(
     con_db,
     DBI::Id(db = "test_database_dm", schema = "dbo", table = "test_1"),
     value = tibble(a = c(5L, 5L, 4L, 2L, 1L), b = 1:5)
   )
-  dbWriteTable(
+  DBI::dbWriteTable(
     con_db,
     DBI::Id(db = "test_database_dm", schema = "dbo", table = "test_2"),
     value = tibble(c = c(1L, 1L, 1L, 5L, 4L), d = c(10L, 11L, 10L, 10L, 11L))
@@ -293,12 +291,12 @@ test_that("Learning from a specific schema in another DB for MSSQL works?", {
   DBI::dbExecute(con_db, "CREATE SCHEMA dm_test")
   DBI::dbExecute(con_db, paste0("USE ", original_dbname))
 
-  dbWriteTable(
+  DBI::dbWriteTable(
     con_db,
     DBI::Id(db = "test_database_dm", schema = "dm_test", table = "test_1"),
     value = tibble(a = c(5L, 5L, 4L, 2L, 1L), b = 1:5)
   )
-  dbWriteTable(
+  DBI::dbWriteTable(
     con_db,
     DBI::Id(db = "test_database_dm", schema = "dm_test", table = "test_2"),
     value = tibble(c = c(1L, 1L, 1L, 5L, 4L), d = c(10L, 11L, 10L, 10L, 11L))
@@ -315,10 +313,10 @@ test_that("Learning from a specific schema in another DB for MSSQL works?", {
 
   # delete database after test
   withr::defer({
-    try(dbExecute(con_db, "DROP TABLE [test_database_dm].[dm_test].[test_2]"))
-    try(dbExecute(con_db, "DROP TABLE [test_database_dm].[dm_test].[test_1]"))
+    try(DBI::dbExecute(con_db, "DROP TABLE [test_database_dm].[dm_test].[test_2]"))
+    try(DBI::dbExecute(con_db, "DROP TABLE [test_database_dm].[dm_test].[test_1]"))
     # dropping schema is unnecessary
-    try(dbExecute(con_db, "DROP DATABASE test_database_dm"))
+    try(DBI::dbExecute(con_db, "DROP DATABASE test_database_dm"))
   })
 
   # test 'get_src_tbl_names()'
@@ -388,9 +386,9 @@ test_that("dm_meta() contents", {
   withr::defer({
     try(walk(
       order_of_deletion,
-      ~ try(dbExecute(con_db, paste0("DROP TABLE ", schema_name_q, ".", .x, " CASCADE")))
+      ~ try(DBI::dbExecute(con_db, paste0("DROP TABLE ", schema_name_q, ".", .x, " CASCADE")))
     ))
-    try(dbExecute(con_db, paste0("DROP SCHEMA ", schema_name_q)))
+    try(DBI::dbExecute(con_db, paste0("DROP SCHEMA ", schema_name_q)))
   })
 
   dm_for_filter_copied <- copy_dm_to(con_db, dm_for_filter(), temporary = FALSE, schema = schema_name)
@@ -415,8 +413,8 @@ test_that("dm_meta() contents", {
       dm_update_zoomed() %>%
       dm_get_tables() %>%
       map(select, -any_of("column_default"), -contains("catalog"), -contains("schema")) %>%
-      map(arrange_all_but_constraint_name) %>%
       map(collect) %>%
+      map(arrange_all_but_constraint_name) %>%
       map(~ if ("constraint_name" %in% colnames(.x)) {
         .x %>% mutate(constraint_name = as.integer(forcats::fct_inorder(constraint_name)))
       } else {
